@@ -280,6 +280,7 @@ read_config (VeConfig *config)
 	FILE *fp;
 	VeSection *section = config->root;
 	char buf[2048];
+	int cnt;
 
 	config->mtime = get_mtime (config->file);
 
@@ -287,6 +288,8 @@ read_config (VeConfig *config)
 	if (fp == NULL)
 		return;
 
+	cnt = 0;
+
 	while (fgets (buf, sizeof (buf), fp) != NULL) {
 		char *nows = buf;
 		char *eq;
@@ -325,6 +328,13 @@ read_config (VeConfig *config)
 			g_free (val);
 		}
 		/* Note: all invalid lines are whacked from the file */
+
+		/* Note this is a hard limit to avoid run away files.
+		   Do we really expect files longer then 5000 lines?
+		   This is to be ultra anal for security's sake. */
+		cnt ++;
+		if (cnt > 5000)
+			break;
 	}
 
 	fclose (fp);
